Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3983)

Unified Diff: chrome/browser/ui/crypto_module_password_dialog.h

Issue 6303004: Cleanup: replace usage of "pk11" with "pkcs11" or "crypto module", as appropriate. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: sorting fix again Created 9 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/crypto_module_password_dialog.h
diff --git a/chrome/browser/ui/pk11_password_dialog.h b/chrome/browser/ui/crypto_module_password_dialog.h
similarity index 56%
rename from chrome/browser/ui/pk11_password_dialog.h
rename to chrome/browser/ui/crypto_module_password_dialog.h
index 4f0deccf3f93cab2363b581f360f576e1f2a719c..a6d9052c9e14dce8649324f25df323e10987411e 100644
--- a/chrome/browser/ui/pk11_password_dialog.h
+++ b/chrome/browser/ui/crypto_module_password_dialog.h
@@ -1,9 +1,9 @@
-// Copyright (c) 2010 The Chromium Authors. All rights reserved.
+// Copyright (c) 2011 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CHROME_BROWSER_UI_PK11_PASSWORD_DIALOG_H_
-#define CHROME_BROWSER_UI_PK11_PASSWORD_DIALOG_H_
+#ifndef CHROME_BROWSER_UI_CRYPTO_MODULE_PASSWORD_DIALOG_H_
+#define CHROME_BROWSER_UI_CRYPTO_MODULE_PASSWORD_DIALOG_H_
#pragma once
#include <string>
@@ -11,7 +11,7 @@
#include "base/callback.h"
namespace base {
-class PK11BlockingPasswordDelegate;
+class CryptoModuleBlockingPasswordDelegate;
}
namespace net {
@@ -22,37 +22,38 @@ class X509Certificate;
namespace browser {
// An enum to describe the reason for the password request.
-enum PK11PasswordReason {
- kPK11PasswordKeygen,
- kPK11PasswordCertEnrollment,
- kPK11PasswordClientAuth,
- kPK11PasswordCertImport,
- kPK11PasswordCertExport,
+enum CryptoModulePasswordReason {
+ kCryptoModulePasswordKeygen,
+ kCryptoModulePasswordCertEnrollment,
+ kCryptoModulePasswordClientAuth,
+ kCryptoModulePasswordCertImport,
+ kCryptoModulePasswordCertExport,
};
-typedef Callback1<const char*>::Type PK11PasswordCallback;
+typedef Callback1<const char*>::Type CryptoModulePasswordCallback;
// Display a dialog, prompting the user to authenticate to unlock
// |module|. |reason| describes the purpose of the authentication and
// affects the message displayed in the dialog. |server| is the name
// of the server which requested the access.
-void ShowPK11PasswordDialog(const std::string& module_name,
+void ShowCryptoModulePasswordDialog(const std::string& module_name,
bool retry,
- PK11PasswordReason reason,
+ CryptoModulePasswordReason reason,
const std::string& server,
- PK11PasswordCallback* callback);
+ CryptoModulePasswordCallback* callback);
-// Returns a PK11BlockingPasswordDelegate to open a dialog and block
+// Returns a CryptoModuleBlockingPasswordDelegate to open a dialog and block
// until returning. Should only be used on a worker thread.
-base::PK11BlockingPasswordDelegate* NewPK11BlockingDialogDelegate(
- PK11PasswordReason reason,
- const std::string& server);
+base::CryptoModuleBlockingPasswordDelegate*
+ NewCryptoModuleBlockingDialogDelegate(
+ CryptoModulePasswordReason reason,
+ const std::string& server);
// Asynchronously unlock |module|, if necessary. |callback| is called when done
// (regardless if module was successfully unlocked or not). Should only be
// called on UI thread.
void UnlockSlotIfNecessary(net::CryptoModule* module,
- browser::PK11PasswordReason reason,
+ browser::CryptoModulePasswordReason reason,
const std::string& server,
Callback0::Type* callback);
@@ -60,10 +61,10 @@ void UnlockSlotIfNecessary(net::CryptoModule* module,
// called when done (regardless if module was successfully unlocked or not).
// Should only be called on UI thread.
void UnlockCertSlotIfNecessary(net::X509Certificate* cert,
- browser::PK11PasswordReason reason,
+ browser::CryptoModulePasswordReason reason,
const std::string& server,
Callback0::Type* callback);
} // namespace browser
-#endif // CHROME_BROWSER_UI_PK11_PASSWORD_DIALOG_H_
+#endif // CHROME_BROWSER_UI_CRYPTO_MODULE_PASSWORD_DIALOG_H_
« no previous file with comments | « chrome/browser/renderer_host/render_message_filter.cc ('k') | chrome/browser/ui/crypto_module_password_dialog_nss.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698